<template>
  <div class="step-card">
    <div class="step-0" v-if="activeIndex == 0">
      <el-form
        :model="ruleForm"
        :rules="rules"
        ref="ruleForm"
        :label-position="'left'"
        label-width="70px"
        class="relate-form"
      >
        <el-form-item label="手机号" prop="phone">
          <el-input
            v-model="ruleForm.phone"
            placeholder="请输入手机号"
          ></el-input>
        </el-form-item>
        <el-form-item label="用户名" prop="username">
          <el-input
            v-model="ruleForm.username"
            placeholder="请输入用户名"
          ></el-input>
        </el-form-item>
      </el-form>

      <div class="btns">
        <div class="cancel" @click="goback">取消</div>
        <div class="ok" @click="gonext">下一步</div>
      </div>
    </div>
    <div class="step-1" v-if="activeIndex == 1">
      <div class="user-auth">
        <div class="name">用户权限</div>
        <div class="tree-box">
          <div class="t">菜单权限</div>
          <el-tree
            :data="data1"
            show-checkbox
            node-key="id"
            :default-expanded-keys="[2, 3]"
            :default-checked-keys="[5]"
            :props="defaultProps1"
          >
          </el-tree>
        </div>
        <!-- <div class="tree-box">
          <div class="t">数据权限</div>
          <el-tree
            :data="data2"
            show-checkbox
            node-key="id"
            :default-expanded-keys="[2, 3]"
            :default-checked-keys="[5]"
            :props="defaultProps2"
          >
          </el-tree>
        </div> -->
      </div>

      <div class="btns">
        <div class="cancel prev" @click="goprev">上一步</div>
        <div class="ok" @click="gonext">下一步</div>
      </div>
    </div>
    <div class="step-2" v-if="activeIndex == 2">
      <div class="t">
        <i class="el-icon-circle-check"></i>
        <span t-h>发送邀请成功！等待关联子账号确认！</span>
      </div>
      <div class="desc">
        我们会通过站内信方式通知您邀约的关联子账号，请推进关联账号的确认。
      </div>
      <div class="btns">
        <div class="ok" @click="goback">完成</div>
      </div>
    </div>
  </div>
</template>

<script>
import { validUser, isPhone } from "@/scripts/validate"; // 正则文件
export default {
  data() {
    return {
      ruleForm: {
        phone: "",
        username: "",
      },
      data1: [
        {
          id: 1,
          label: "一级 1",
          children: [
            {
              id: 4,
              label: "二级 1-1",
              children: [
                {
                  id: 9,
                  label: "三级 1-1-1",
                },
                {
                  id: 10,
                  label: "三级 1-1-2",
                },
              ],
            },
          ],
        },
        {
          id: 2,
          label: "一级 2",
          children: [
            {
              id: 5,
              label: "二级 2-1",
            },
            {
              id: 6,
              label: "二级 2-2",
            },
          ],
        },
        {
          id: 3,
          label: "一级 3",
          children: [
            {
              id: 7,
              label: "二级 3-1",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
          ],
        },
      ],
      data2: [
        {
          id: 1,
          label: "一级 1",
          children: [
            {
              id: 4,
              label: "二级 1-1",
              children: [
                {
                  id: 9,
                  label: "三级 1-1-1",
                },
                {
                  id: 10,
                  label: "三级 1-1-2",
                },
              ],
            },
          ],
        },
        {
          id: 2,
          label: "一级 2",
          children: [
            {
              id: 5,
              label: "二级 2-1",
            },
            {
              id: 6,
              label: "二级 2-2",
            },
          ],
        },
        {
          id: 3,
          label: "一级 3",
          children: [
            {
              id: 7,
              label: "二级 3-1",
            },
            {
              id: 8,
              label: "二级 3-2",
            },
          ],
        },
      ],
      defaultProps2: {
        children: "children",
        label: "label",
      },
      defaultProps1: {
        children: "children",
        label: "label",
      },
      rules: {
        phone: [
          { required: true, message: "请输入手机号", trigger: "blur" },
          { validator: isPhone, trigger: "blur" },
        ],
        // username: [{ validator: validUser, trigger: "blur" }],
      },
    };
  },
  props: {
    titleList: Array,
    activeIndex: {
      type: Number,
      default: 0,
    },
  },
  computed: {},
  methods: {
    goback() {
      this.activeIndex = 0
      this.$emit("goback");
    },
    goprev() {
      this.activeIndex--;
      let next = this.activeIndex;
      this.$emit("goto", next);
    },
    gonext() {
      let next = this.activeIndex;
      if (this.activeIndex < 2) {
        next = ++this.activeIndex;
      }
      this.$emit("goto", next);
    },
    getClass(i) {
      if (this.activeIndex == i) {
        return "active-box";
      } else if (this.activeIndex > i) {
        return "done-box";
      } else {
        return "";
      }
    },
  },
};
</script>

<style lang="scss" scoped>
.step-card {
  display: flex;
  justify-content: center;
  .relate-form::v-deep {
    .el-input__inner {
      color: #3d3d3d;
      border-radius: 3px;
      height: 32px;
      width: 350px;
      border: 1px solid #c0c5cc;
      line-height: 32px;
    }
  }
  .btns {
    display: flex;
    justify-content: center;
    margin-top: 50px;
    .cancel {
      width: 80px;
      height: 40px;
      display: flex;
      justify-content: center;
      align-items: center;
      border-radius: 3px;
      box-sizing: border-box;
      border: 1px solid #0064ff;
      color: #0064ff;
      cursor: pointer;
      margin-right: 10px;    line-height: 40px;

    }
    .prev {
      width: 96px;
    }
    .ok {
      border-radius: 3px;
      background: #0064ff;
      width: 96px;
      height: 40px;
      display: flex;line-height: 40px;
      justify-content: center;
      cursor: pointer;
      align-items: center;
      color: #ffffff;
    }
  }
  .user-auth {
    display: flex;
    .name {
      font-size: 14px;
      color: #3d3d3d;
      margin-right: 20px;
    }
    .tree-box {
      .t {
        height: 32px;
        background: #f0f5fa;
        border-radius: 3px 3px 0px 0px;
        line-height: 32px;
        text-align: center;
        border-bottom: 1px solid #c0c5cc;
      }
      width: 336px;
      height: 480px;
      border: 1px solid #c0c5cc;
      margin-right: 20px;
      box-sizing: border-box;
    }
  }
  .step-2 {
    .t {
      display: flex;
      align-items: center;
      justify-content: center;
      i {
        font-size: 32px;
        color: limegreen;
        margin-right: 10px;
      }
      .t-h {
        font-size: 18px;
        color: #3d3d3d;
        line-height: 24px;
      }
      
    }
    .desc {
        font-size: 14px;
        margin-top: 14px;
        color: #999999;
        line-height: 20px;
      }
  }
}
</style>